#
# spec file for package LHAPDF
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_name libLHAPDF
%define execname lhapdf

Name:           LHAPDF
Version:        6.1.6
Release:        3.2
Summary:        A library for unified and easy to use interface to modern PDF sets
License:        GPL-3.0
Group:          Development/Libraries/C and C++
Url:            http://lhapdf.hepforge.org
Source:         http://www.hepforge.org/archive/lhapdf/%{name}-%{version}.tar.gz
BuildRequires:  boost-devel >= 1.53.0
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  texlive-latex-bin
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LHAPDF provides a unified and easy to use interface to modern PDF
sets. It is designed to work not only with individual PDF sets but
also with the more recent multiple "error" sets. It can be viewed as
the successor to PDFLIB, incorporating many of the older sets found in
the latter, including pion and photon PDFs. In LHAPDF the computer
code and input parameters/grids are separated thus allowing more easy
updating and no limit to the expansion possibilities. The code and
data sets can be downloaded together or inidivually as desired. From
version 4.1 onwards a configuration script facilitates the
installation of LHAPDF.

%package -n %{so_name}
Summary:        A library for unified and easy to use interface to modern PDF sets
Group:          Development/Libraries/C and C++

%description -n %{so_name}
LHAPDF provides a unified and easy to use interface to modern PDF
sets. It is designed to work not only with individual PDF sets but
also with the more recent multiple "error" sets. It can be viewed as
the successor to PDFLIB, incorporating many of the older sets found in
the latter, including pion and photon PDFs. In LHAPDF the computer
code and input parameters/grids are separated thus allowing more easy
updating and no limit to the expansion possibilities. The code and
data sets can be downloaded together or inidivually as desired. From
version 4.1 onwards a configuration script facilitates the
installation of LHAPDF.

This package provides the shared library for %{name}.

%package devel
Summary:        A library for unified and easy to use interface to modern PDF sets
Group:          Development/Libraries/C and C++
Requires:       %{so_name} = %{version}
Requires:       boost-devel

%description devel
LHAPDF provides a unified and easy to use interface to modern PDF
sets. It is designed to work not only with individual PDF sets but
also with the more recent multiple "error" sets. It can be viewed as
the successor to PDFLIB, incorporating many of the older sets found in
the latter, including pion and photon PDFs. In LHAPDF the computer
code and input parameters/grids are separated thus allowing more easy
updating and no limit to the expansion possibilities. The code and
data sets can be downloaded together or inidivually as desired. From
version 4.1 onwards a configuration script facilitates the
installation of LHAPDF.

This package provides the header and source files for development with
%{name}.

%package -n python-%{name}
Summary:        A library for unified and easy to use interface to modern PDF sets
Group:          Development/Libraries/C and C++
Requires:       %{so_name} = %{version}
Requires:       python

%description -n python-%{name}
LHAPDF provides a unified and easy to use interface to modern PDF
sets. It is designed to work not only with individual PDF sets but
also with the more recent multiple "error" sets. It can be viewed as
the successor to PDFLIB, incorporating many of the older sets found in
the latter, including pion and photon PDFs. In LHAPDF the computer
code and input parameters/grids are separated thus allowing more easy
updating and no limit to the expansion possibilities. The code and
data sets can be downloaded together or inidivually as desired. From
version 4.1 onwards a configuration script facilitates the
installation of LHAPDF.

This package provides the python wrapper for %{name}.

%prep
%setup -q

%build
%configure --disable-static --docdir=%{_docdir}/%{name}/
make %{?_smp_mflags}

%install
%make_install

find %{buildroot}%{_libdir}/ -name "*.la" -delete

%post -n %{so_name}
/sbin/ldconfig

%postun -n %{so_name}
/sbin/ldconfig

%files -n %{so_name}
%defattr(-, root, root)
%{_libdir}/*.so

%files devel
%defattr(-, root, root)
%doc AUTHORS ChangeLog COPYING
%{_bindir}/%{execname}
%{_bindir}/%{execname}-*
%{_datadir}/%{name}/
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{execname}.pc

%files -n python-%{name}
%defattr(-, root, root)
%{python_sitearch}/%{name}-*.egg-info
%{python_sitearch}/%{execname}.so

%changelog
* Mon Feb  1 2016 badshah400@gmail.com
- Update to version 6.1.6:
  + Add canonical PDF.orderQCD property to Python PDF, to replace
    PDF.qcdOrder.
  + Add PDF::quarkMass and PDF::quarkThreshold methods to C++ and
    Python.
  + Fix quark integer ID mapping to Down/Up metadata keys in
    AlphaS factory routine.
  + Add a cstr_to_fstr function to LHAGlue.cc, for improved C++ to
    Fortran string conversion (handling length limits, padding
    rather than zero-termination, etc.)
  + Add PDF::print() protection against being unable to read the
    PDF set index file, so there isn't a crash for the trivial
    reason of on-screen printout formatting when the data path is
    restricted with trailing ::.
  + Fixes to the lhapdf script. Thanks again to Dmitry Kalinkin
    for a patch.
  + Add missing getlam4 and getlam5 functions to Fortran
    interface. Thanks to Dmitry Kalinkin for the patch.
  + Update Cython and Python interfaces to support Python3 syntax.
    Thanks to Vitaly Yermolchyk for the patches!
  + Update to even newer boost.m4
  + Don't append the install prefix to path searches if
    $LHAPDF_DATA_PATH ends with a double-colon, ::.
  + De-inline the availablePDFSets() function, and veto duplicate
    set names.
  + Determine number of parameter variation members by counting
    number of "+" signs in ErrorType, e.g. "replicas+as+mc+mb+mt".
  + Added a new checkPdfType() member function to PDFSet class.
  + Added support for combined PDF+alphaS sets via new ErrorType
    values, i.e. "replicas+as", "hessian+as" and "symmhessian+as".
  + Updating AUTHORS notice to final EPJC paper reference, and
    adding a final citation reminder message via the Config
    destructor.
  + src/Factories.cc: Adding a set of expandPDFsStr(),
    decodePDFStr and decodePDFsStr functions to be used for
    handling more general PDF strings of the sort that will be
    used in the CompositePDF factory system.
  + Adding a default constructor and knotarrays() accessor to
    GridPDF, as requested by Nathan Hartland.
  + Remove abs(...) twice in function
    PDFSet::randomValueFromHessian to correct a mistake in Eq.
    (6.5) of arXiv:1205.4024v2.  The correction is necessary to
    ensure that correlations are preserved when converting a
    Hessian PDF set to a Monte Carlo PDF set.
- Drop LHAPDF-boost-configure-for-GCC5.patch, incorporated
  upstream.
* Thu Jun 25 2015 badshah400@gmail.com
- Add LHAPDF-boost-configure-for-GCC5.patch to fix autoconf
  boost macros lookup with GCC5; patch taken from boost.m4
  upstream [https://github.com/tsuna/boost.m4].
* Fri Mar 20 2015 badshah400@gmail.com
- Update to version 6.1.5:
  + Better error handling in PDF index lookup, including clearer
    reporting of set-unmatched PDF IDs and member numbers which
    are out of range for a valid set.
  + Restoring original active set member in LHAGlue metadata get*
    functions which were previously switching focus as a result of
    calling loadMember() to get numerical grid data.
  + Making LHAGlue Fortran interface switch the current set slot
    more coherently (has_photon is the exception).
  + Attempt to use Threshold* metadata keys for Fortran
    getthresholdm_ and old C++ wrapper getThreshold. Not yet fully
    supported in the rest of the system but we may as well
    pre-empt it while editing LHAGlue.cc.
  + Add missing getdescm_ and getdesc_ Fortran functions.
  + Add missing Fortran getdatapath function, cf. LHAPDF5 but with
    colon separators between multiple paths if appropriate.
  + Add Fortran lhapdf_getpdfsetlist function, returning the list
    of available PDF sets as a space-separated string. Note the
    lhapdf_ prefix -- this is the intended 'namespace' form for a
    new Fortran interface at some point.
  + Remove obsolete config flags from lhapdf.conf
  + examples/compatibility.cc: Simplify compatibility macro
    checking.
  + Add parsing and use of the internal PID data line in
    GridPDF.cc, in preference to the PDF::flavors() method. This
    fixes a bug, since flavors() was sorting the list, meaning
    that data files without monotonically sorted PID columns would
    wrongly assign PDFs to PIDs.
  + Added new ContinuationExtrapolator to provide same
    extrapolation as in the MSTW standalone code (and LHAPDF5 when
    using MSTW sets).
  + Better code organisation and protection against out-of-bounds
    array accesses in log-bicubic interpolator.
  + Fallback to bilinear interpolator if using bicubic
    interpolator with only 2 or 3 Q2 knots in a subgrid.
  + Improve LHAGlue info messages to not specify that particular
    generators are being used.
- LHAPDF-devel should require boost-devel.
* Sat Sep  6 2014 badshah400@gmail.com
- Update to version 6.1.4:
  - Adding multiset variants of the 5 getmin/max LHAGlue
    functions
  - Adding the 'unofficial' getminmax Fortran function to
    LHAGlue.cc
  - Treat PID 0 as an alias for 21 in PDF::hasFlavor as well as
    the PDF::xf* functions
  - Clarify in lhapdf script help that 'list' by default shows all
    available sets, not those installed on the user's system
  - Update CONFIGFLAGS docs to fix some errors w.r.t. actual flag
    usage
  - Treat a DataVersion of 0 as unvalidated: valid numbers now
    start at 1
  - Remove the LHAPDF ID from the warning printout about
    unvalidated PDFs, since in that case there will usually be no
    standard ID number and it just gets unhelpfully reported as -1
  - Detect and report improperly terminated grid files (ones
    missing a --- final line)
  - Replace asserts with exceptions and improve subgrid error
    reporting in GridPDF
  - Report the value of Q2 that causes a subgrid-finding failure
  - Improve testgrid to use PDFNAME/MEMNUM arg syntax
  - Forbid compilation if the demon combination of Boost < 1.47
    and	GCC >= 4.6, with a serious bug in BOOST_FOREACH, is found:
    http://code-muse.com/2013/08/06/boostforeach-and-compiler-bugs
  - Improved AlphaS ODE solver performance.
* Sat Jun 21 2014 badshah400@gmail.com
- Update to version 6.1.3:
  + tests/Makefile.am: Add appropriate programs to "make
    installcheck"
  + wrappers/python/Makefile.am: 'make distcheck' and
    out-of-source builds should work now
  + Add CVMFS and AFS downloading (by preference) to the lhapdf
    script, as well as user-configurable download sources and
    tarball removal
  + Fix bug in PDF::qcdOrder method, and deprecate that method in
    favour of orderQCD (to match AlphaS and the flag name).
  + Further improvements to error messages when trying to load an
    invalid PDF
  + Tweak output of testalphas.cc
  + Adding first make check targets (requires CT10nlo to be
    installed)
  + Flavour thresholds in alpha_s solvers, and threshold subgrids
    from ODE solver (by Karl Nordstrom)
  + Add accessors to a PDF's AlphaS object and to an AlphaS' QCD
    order
  + Add mapping of reweighting functions into Python
  + Fix compiler warnings re. unused variables in LHAGlue.h and
    AlphaS.h headers
  + Fix attempted use of non-existent std::vector::find method
  + Change source name of analyticpdf example
  + Adding a mini-constructor to PDF to make sure that _forcePos
    is set to a sane default value.
* Wed Jun 18 2014 badshah400@gmail.com
- Update to version 6.1.2:
  + Fix HWLHAPDF behaviour in pdfset
- Changes from version 6.1.1:
  + Modify printout in PDFLIB backwards compatibility routine to
    avoid confusion for some HERWIG use cases
  + Adding warnings about mismatching alpha_s in reweighting, with
    a default tolerance of 5%%
  + Add LHAPDF/Reweighting.h with a few handy functions for doing
    'naive' PDF reweighting
  + Replace all internal uses of "foreach" with explicit
    BOOST_FOREACH until C++11
  + Remigrate all NNPDF sets to remove duplicate Qmax points
  + Adding initLHAPDF() and a few other do-nothing compatibility
    functions.
* Sun May  4 2014 badshah400@gmail.com
- Update to version 6.1.0:
  + Lots of changes since previously packaged version, see
    /usr/share/doc/packages/ChangeLog for a full list
  + Now installs a pkgconfig file (introduces BuildRequires on
    pkg-config)
  + Requires boost >= 1.53.0 (not available on <= 12.3).
- Unnecessary rpaths and linker flags have been properly removed
  from lhapdf-config by upstream, remove the temporary workaround
  which was put in the spec file.
* Tue Apr 29 2014 badshah400@gmail.com
- Manually remove unnecessary rpath and linker flags from
  generated script /usr/bin/lhapdf-config.
* Thu Apr 17 2014 badshah400@gmail.com
- Correct License tag in spec file: GPL-3.0 instead of GPL-2.0.
* Mon Dec  9 2013 badshah400@gmail.com
- Initial version
